@@ -24,7 +24,7 @@
 #' @keywords array logic iteration univar
 #' @export
 rowCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
-                      na.rm = FALSE, dim. = dim(x), ..., useNames = NA) {
+                      na.rm = FALSE, dim. = dim(x), ..., useNames = TRUE) {
   # Argument 'x':
   if (is.matrix(x)) {
   } else if (is.vector(x)) {
@@ -79,20 +79,18 @@ rowCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
     counts <- as.integer(counts)
     
     # Update names attribute?
-    if (!is.na(useNames)) {
-      if (useNames) {
-        if (!is.null(names)) {
-          if (!is.null(rows)) {
-            names <- names[rows]
-            # Zero-length attribute? Keep behavior same as base R function
-            if (length(names) == 0L) names <- NULL
-          }
-          names(counts) <- names
+    if (useNames) {
+      if (!is.null(names)) {
+        if (!is.null(rows)) {
+          names <- names[rows]
+          # Zero-length attribute? Keep behavior same as base R function
+          if (length(names) == 0L) names <- NULL
         }
-      } else {
-        names(counts) <- NULL
+        names(counts) <- names
       }
-    }    
+    } else {
+      names(counts) <- NULL
+    }
   }
   counts
 }
@@ -101,7 +99,7 @@ rowCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
 #' @rdname rowCounts
 #' @export
 colCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
-                      na.rm = FALSE, dim. = dim(x), ..., useNames = NA) {
+                      na.rm = FALSE, dim. = dim(x), ..., useNames = TRUE) {
   # Argument 'x':
   if (is.matrix(x)) {
   } else if (is.vector(x)) {
@@ -156,20 +154,18 @@ colCounts <- function(x, rows = NULL, cols = NULL, value = TRUE,
     counts <- as.integer(counts)
     
     # Update names attribute?
-    if (!is.na(useNames)) {
-      if (useNames) {
-        if (!is.null(names)) {
-          if (!is.null(cols)) {
-            names <- names[cols]
-            # Zero-length attribute? Keep behavior same as base R function
-            if (length(names) == 0L) names <- NULL        
-          }
-          names(counts) <- names
+    if (useNames) {
+      if (!is.null(names)) {
+        if (!is.null(cols)) {
+          names <- names[cols]
+          # Zero-length attribute? Keep behavior same as base R function
+          if (length(names) == 0L) names <- NULL        
         }
-      } else {
-        names(counts) <- NULL
+        names(counts) <- names
       }
-    }    
+    } else {
+      names(counts) <- NULL
+    }
   }
   counts
 }
