@@ -16,13 +16,13 @@
 #' @keywords array iteration robust univar
 #' @export
 rowDiffs <- function(x, rows = NULL, cols = NULL,
-                     lag = 1L, differences = 1L, dim. = dim(x), ..., useNames = NA) {
+                     lag = 1L, differences = 1L, dim. = dim(x), ..., useNames = TRUE) {
   .Call(C_rowDiffs, x, dim., rows, cols, lag, differences, TRUE, useNames)
 }
 
 #' @rdname rowDiffs
 #' @export
 colDiffs <- function(x, rows = NULL, cols = NULL,
-                     lag = 1L, differences = 1L, dim. = dim(x), ..., useNames = NA) {
+                     lag = 1L, differences = 1L, dim. = dim(x), ..., useNames = TRUE) {
   .Call(C_rowDiffs, x, dim., rows, cols, lag, differences, FALSE, useNames)
 }
