@@ -15,7 +15,7 @@
 #' @keywords array iteration robust univar
 #' @export
 rowSums2 <- function(x, rows = NULL, cols = NULL, na.rm = FALSE,
-                       dim. = dim(x), ..., useNames = NA) {
+                       dim. = dim(x), ..., useNames = TRUE) {
   has_nas <- TRUE
   .Call(C_rowSums2, x, dim., rows, cols, na.rm, has_nas, TRUE, useNames)
 }
@@ -23,7 +23,7 @@ rowSums2 <- function(x, rows = NULL, cols = NULL, na.rm = FALSE,
 #' @rdname rowSums2
 #' @export
 colSums2 <- function(x, rows = NULL, cols = NULL, na.rm = FALSE,
-                       dim. = dim(x), ..., useNames = NA) {
+                       dim. = dim(x), ..., useNames = TRUE) {
   has_nas <- TRUE
   .Call(C_rowSums2, x, dim., rows, cols, na.rm, has_nas, FALSE, useNames)
 }
