@@ -2,31 +2,52 @@
 #'
 #' Variance estimates for each row (column) in a matrix.
 #'
-#' @param x A \code{\link[base]{numeric}} NxK \code{\link[base]{matrix}}.
+#' @inheritParams rowAlls
+#' @inheritParams rowDiffs
 #'
-#' @param rows,cols A \code{\link[base]{vector}} indicating subset of rows
-#' (and/or columns) to operate over. If \code{\link[base]{NULL}}, no subsetting
-#' is done.
-#'
-#' @param na.rm If \code{\link[base:logical]{TRUE}}, missing values
-#' are excluded first, otherwise not.
+#' @param refine If \code{\link[base:logical]{TRUE}}, `center` is NULL, and
+#' \code{x} is \code{\link[base]{numeric}}, then extra effort is used to
+#' calculate the average with greater numerical precision, otherwise not.
 #'
 #' @param center (optional; a vector or length N (K)) If the row (column)
 #' means are already estimated, they can be pre-specified using this argument.
-#' This avoid re-estimating them again. (*Warning: If biased estimated are
-#' given, the estimate of the spread will also be biased.*)
+#' This avoid re-estimating them again.
+#' _Warning: It is important that a non-biased sample mean estimate is passed.
+#' If not, then the variance estimate of the spread will also be biased._
 #' If NULL (default), the row/column means are estimated internally.
 #'
-#' @param dim. An \code{\link[base]{integer}} \code{\link[base]{vector}} of
-#' length two specifying the dimension of \code{x}, also when not a
-#' \code{\link[base]{matrix}}.
-#'
 #' @param ... Additional arguments passed to \code{rowMeans()} and
 #' \code{rowSums()}.
 #'
 #' @return Returns a \code{\link[base]{numeric}} \code{\link[base]{vector}} of
 #' length N (K).
 #'
+#' @section Providing center estimates:
+#' The sample variance is estimated as
+#'
+#'   \eqn{n/(n-1) * mean((x - center)^2)},
+#'
+#' where \eqn{center} is estimated as the sample mean, by default.
+#' In matrixStats (< 0.58.0),
+#'
+#'   \eqn{n/(n-1) * (mean(x^2) - center^2)}
+#'
+#' was used.  Both formulas give the same result _when_ `center` is the
+#' sample mean estimate.
+#'
+#' Argument `center` can be used to provide an already existing estimate.
+#' It is important that the sample mean estimate is passed.
+#' If not, then the variance estimate of the spread will be biased.
+#'
+#' For the time being, in order to lower the risk for such mistakes,
+#' argument `center` is occasionally validated against the sample-mean
+#' estimate.  If a discrepancy is detected, an informative error is
+#' provided to prevent incorrect variance estimates from being used.
+#' For performance reasons, this check is only performed once every 50 times.
+#' The frequency can be controlled by R option `matrixStats.vars.formula.freq`,
+#' whose default can be set by environment variable
+#' `R_MATRIXSTATS_VARS_FORMULA_FREQ`.
+#'
 #' @example incl/rowMethods.R
 #'
 #' @author Henrik Bengtsson
@@ -35,19 +56,21 @@
 #' \code{\link[base]{colSums}}().
 #' @keywords array iteration robust univar
 #' @export
-rowVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
-                    dim. = dim(x), ...) {
-  dim. <- as.integer(dim.)
-
+rowVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, refine = TRUE, center = NULL,
+                    dim. = dim(x), ..., useNames = TRUE) {
   if (is.null(center)) {
-    na.rm <- as.logical(na.rm)
     has_nas <- TRUE
-    sigma2 <- .Call(C_rowVars, x, dim., rows, cols, na.rm, has_nas, TRUE)
+    sigma2 <- .Call(C_rowVars, x, dim., rows, cols, na.rm, refine, has_nas, TRUE, useNames)
     return(sigma2)
   }
 
   ## https://github.com/HenrikBengtsson/matrixStats/issues/187
   centerOnUse("rowVars")
+  
+  ## BACKWARD COMPATIBILITY: matrixStats (<= 0.57.0) returns names
+  ## when !is.null(center), which is tested by DelayedMatrixStats
+  ## and sparseMatrixStats
+  names <- rownames(x)
 
   # Apply new dimensions
   if (!identical(dim(x), dim.)) dim(x) <- dim.
@@ -59,7 +82,7 @@ rowVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
       validateScalarCenter(center, nrow(x), "rows")
       center <- rep(center, times = nrow(x))
     } else {
-      stop("Argument 'center' should be of the same length as number of rows of 'x': ", length(center), " != ", nrow(x))
+      stop(sprintf("Argument '%s' should be of the same length as number of %s of '%s': %d != %d", "center", "rows", "x", length(center), nrow(x)))
     }
   }
   if (!is.null(rows)) center <- center[rows]
@@ -74,7 +97,20 @@ rowVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
 
   # Nothing to do?
   if (ncol <= 1L) {
+
     x <- rep(NA_real_, times = nrow(x))
+    
+    # Update names attribute?
+    if (useNames) {
+      if (!is.null(names)) {
+        if (!is.null(rows)) {
+          names <- names[rows]
+          # Zero-length attribute? Keep behavior same as base R function
+          if (length(names) == 0L) names <- NULL
+        }
+        names(x) <- names
+      }
+    }
     return(x)
   }
 
@@ -98,11 +134,6 @@ rowVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
     n <- ncol
   }
 
-  ## BACKWARD COMPATIBILITY: matrixStats (<= 0.57.0) returns names
-  ## when !is.null(center), which is tested by DelayedMatrixStats
-  ## and sparseMatrixStats
-  names <- rownames(x)
-
   validate <- validateVarsCenterFormula()
   if (!validate) {
     ## The primary formula for estimating the sample variance
@@ -111,54 +142,66 @@ rowVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
     ## just like for stats::var() - not Inf, e.g. var(c(0,Inf)) == NaN
     x[is.infinite(center)] <- NaN
     x <- rowMeans(x, na.rm = na.rm)
-    x <- x * (n / (n - 1))
-    names(x) <- names
-    return(x)
+  } else {
+    ## The alternative formula for estimating the sample variance
+    x2 <- x * x
+    x2 <- rowMeans(x2, na.rm = na.rm)
+    x2 <- (x2 - center^2)
+    
+    ## The primary formula for estimating the sample variance
+    x <- (x - center)^2
+    x <- rowMeans(x, na.rm = na.rm)
+    
+    ## SPECIAL: The variance estimate when the mean estimate is infinite should be NaN
+    ## just like for stats::var() - not Inf, e.g. var(c(0,Inf)) == NaN
+    x[is.infinite(center)] <- NaN
+    
+    equal <- all.equal(x, x2, check.attribute = FALSE)
+    x2 <- NULL
+    if (!isTRUE(equal)) {
+      fcn <- getOption("matrixStats.vars.formula.onMistake", "defunct")
+      fcn <- switch(fcn, deprecated = .Deprecated, .Defunct)
+      when <- attr(validate, "when", exact = TRUE)
+      fcn(msg = sprintf("Detected incorrect use of argument 'center' for rowVars() or rowSds(). The value of 'center' does not meet the assumption that estimating the variance using the 'primary' or the 'alternative' formula does not matter as they should give the same results, which suggests a misunderstanding on what argument 'center' should be. Please see help(\"rowVars\", package = \"%s\"). The reason was: %s (this validation is performed %s per R option 'matrixStats.vars.formula.freq')", .packageName, equal, when))
+    }
   }
-
-  ## The alternative formula for estimating the sample variance
-  x2 <- x * x
-  x2 <- rowMeans(x2, na.rm = na.rm)
-  x2 <- (x2 - center^2)
-
-  ## The primary formula for estimating the sample variance
-  x <- (x - center)^2
-  x <- rowMeans(x, na.rm = na.rm)
-  
-  ## SPECIAL: The variance estimate when the mean estimate is infinite should be NaN
-  ## just like for stats::var() - not Inf, e.g. var(c(0,Inf)) == NaN
-  x[is.infinite(center)] <- NaN
-
-  equal <- all.equal(x, x2, check.attributes = FALSE)
-  x2 <- NULL
-  if (!isTRUE(equal)) {
-    fcn <- getOption("matrixStats.vars.formula.onMistake", "deprecated")
-    fcn <- switch(fcn, deprecated = .Deprecated, .Defunct)
-    fcn(msg = sprintf("rowVars() was called with a 'center' argument that does not meet the assumption that estimating the variance using the 'primary' or the 'alternative' formula does not matter as they should give the same results. This suggests a misunderstanding on what argument 'center' should be. The reason was: %s", equal))
-  }
-  
   x <- x * (n / (n - 1))
-  names(x) <- names
+  
+  # Preserve names attribute?
+  if (useNames) {
+    if (!is.null(names)) {
+      if (!is.null(rows)) {
+        names <- names[rows]
+        # Zero-length attribute? Keep behavior same as base R function
+        if (length(names) == 0L) names <- NULL
+      }
+      names(x) <- names
+    }
+  } else {
+    names(x) <- NULL
+  }
+
   x  
 }
 
 
 #' @rdname rowVars
 #' @export
-colVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
-                    dim. = dim(x), ...) {
-  dim. <- as.integer(dim.)
-
+colVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, refine = TRUE, center = NULL,
+                    dim. = dim(x), ..., useNames = TRUE) {
   if (is.null(center)) {
-    dim. <- as.integer(dim.)
-    na.rm <- as.logical(na.rm)
     has_nas <- TRUE
-    sigma2 <- .Call(C_rowVars, x, dim., rows, cols, na.rm, has_nas, FALSE)
+    sigma2 <- .Call(C_rowVars, x, dim., rows, cols, na.rm, refine, has_nas, FALSE, useNames)
     return(sigma2)
   }
 
   ## https://github.com/HenrikBengtsson/matrixStats/issues/187
   centerOnUse("colVars")
+  
+  ## BACKWARD COMPATIBILITY: matrixStats (<= 0.57.0) returns names
+  ## when !is.null(center), which is tested by DelayedMatrixStats
+  ## and sparseMatrixStats
+  names <- colnames(x)
 
   # Apply new dimensions
   if (!identical(dim(x), dim.)) dim(x) <- dim.
@@ -170,7 +213,7 @@ colVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
       validateScalarCenter(center, ncol(x), "columns")
       center <- rep(center, times = ncol(x))
     } else {
-      stop("Argument 'center' should be of the same length as number of columns of 'x': ", length(center), " != ", ncol(x))
+      stop(sprintf("Argument '%s' should be of the same length as number of %s of '%s': %d != %d", "center", "columns", "x", length(center), ncol(x)))
     }
   }
   if (!is.null(cols)) center <- center[cols]
@@ -185,7 +228,22 @@ colVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
 
   # Nothing to do?
   if (nrow <= 1L) {
+
     x <- rep(NA_real_, times = ncol(x))
+    
+    # Update names attribute?
+    if (useNames) {
+      if (!is.null(names)) {
+        if (!is.null(cols)) {
+          names <- names[cols]
+          # Zero-length attribute? Keep behavior same as base R function
+          if (length(names) == 0L) names <- NULL         
+        }
+        names(x) <- names
+      }
+    } else {
+      names(x) <- NULL
+    }
     return(x)
   }
 
@@ -208,11 +266,6 @@ colVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
     # Assuming no missing values
     n <- nrow
   }
-
-  ## BACKWARD COMPATIBILITY: matrixStats (<= 0.57.0) returns names
-  ## when !is.null(center), which is tested by DelayedMatrixStats
-  ## and sparseMatrixStats
-  names <- names(x)
   
   validate <- validateVarsCenterFormula()
   if (!validate) {
@@ -224,35 +277,46 @@ colVars <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, center = NULL,
     ## SPECIAL: The variance estimate when the mean estimate is infinite should be NaN
     ## just like for stats::var() - not Inf, e.g. var(c(0,Inf)) == NaN
     x[is.infinite(center)] <- NaN
-    x <- x * (n / (n - 1))
-    names(x) <- names
-    return(x)
+  } else {
+    ## The alternative formula for estimating the sample variance
+    x2 <- x * x
+    x2 <- colMeans(x2, na.rm = na.rm)
+    x2 <- (x2 - center^2)
+    
+    ## The primary formula for estimating the sample variance
+    for (cc in seq_len(ncol(x))) {
+      x[, cc] <- (x[, cc] - center[cc])^2
+    }
+    x <- colMeans(x, na.rm = na.rm)
+    
+    ## SPECIAL: The variance estimate when the mean estimate is infinite should be NaN
+    ## just like for stats::var() - not Inf, e.g. var(c(0,Inf)) == NaN
+    x[is.infinite(center)] <- NaN
+    
+    equal <- all.equal(x, x2)
+    x2 <- NULL
+    if (!isTRUE(equal)) {
+      fcn <- getOption("matrixStats.vars.formula.onMistake", "defunct")
+      fcn <- switch(fcn, deprecated = .Deprecated, .Defunct)
+      when <- attr(validate, "when", exact = TRUE)
+      fcn(msg = sprintf("Detected incorrect use of argument 'center' for colVars() or colSds(). The value of 'center' does not meet the assumption that estimating the variance using the 'primary' or the 'alternative' formula does not matter as they should give the same results, which suggests a misunderstanding on what argument 'center' should be. Please see help(\"rowVars\", package = \"%s\"). The reason was: %s (this validation is performed %s per R option 'matrixStats.vars.formula.freq')", .packageName, equal, when))
+    }
   }
-
-  ## The alternative formula for estimating the sample variance
-  x2 <- x * x
-  x2 <- colMeans(x2, na.rm = na.rm)
-  x2 <- (x2 - center^2)
-
-  ## The primary formula for estimating the sample variance
-  for (cc in seq_len(ncol(x))) {
-    x[, cc] <- (x[, cc] - center[cc])^2
-  }
-  x <- colMeans(x, na.rm = na.rm)
+  x <- x * (n / (n - 1))  
   
-  ## SPECIAL: The variance estimate when the mean estimate is infinite should be NaN
-  ## just like for stats::var() - not Inf, e.g. var(c(0,Inf)) == NaN
-  x[is.infinite(center)] <- NaN
-
-  equal <- all.equal(x, x2)
-  x2 <- NULL
-  if (!isTRUE(equal)) {
-    fcn <- getOption("matrixStats.vars.formula.onMistake", "deprecated")
-    fcn <- switch(fcn, deprecated = .Deprecated, .Defunct)
-    fcn(sprintf("colVars() was called with a 'center' argument that does not meet the assumption that estimating the variance using the 'primary' or the 'alternative' formula does not matter as they should give the same results. This suggests a misunderstanding on what argument 'center' should be. The reason was: %s", equal))
+  # Preserve names attribute?
+  if (useNames) {
+    if (!is.null(names)) {
+      if (!is.null(cols)) {
+        names <- names[cols]
+        # Zero-length attribute? Keep behavior same as base R function
+        if (length(names) == 0L) names <- NULL         
+      }
+      names(x) <- names
+    }
+  } else {
+    names(x) <- NULL
   }
-  
-  x <- x * (n / (n - 1))
-  names(x) <- names
+
   x  
 }
