@@ -1,4 +1,8 @@
 #include <Rinternals.h> /* R_xlen_t, ... */
+#include <Rversion.h>   /* R_VERSION, R_Version() */
+
+/* Needed if compiled prior to 4.5.0 with STRICT_R_HEADERS */
+#include <float.h>
 
 #ifndef R_INT_MIN
 #define R_INT_MIN -INT_MAX
@@ -27,18 +31,10 @@
 /* As in <R>/src/include/Defn.h */
 #ifdef HAVE_LONG_DOUBLE
 #define LDOUBLE long double
+#define LDOUBLE_ALLOC(n) R_allocLD(n)
 #else
 #define LDOUBLE double
-#endif
-
-/* Backward compatibility with R (< 3.0.0)
-   As in <R>/src/include/Rinternals.h */
-#ifndef R_XLEN_T_MAX
-  typedef int R_xlen_t;
-  #define R_XLEN_T_MAX R_LEN_T_MAX
-  #ifndef xlength
-    #define xlength length
-  #endif
+#define LDOUBLE_ALLOC(n) ((double*) R_alloc(n, sizeof(double)))
 #endif
 
 
