@@ -7,11 +7,15 @@
 #include <Rdefines.h>
 #include "000.types.h"
 #include "colCounts_lowlevel.h"
+#include "naming.h"
 
-SEXP colCounts(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP value, SEXP what, SEXP naRm, SEXP hasNA) {
+SEXP colCounts(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP value, SEXP what, SEXP naRm, SEXP hasNA, SEXP useNames) {
   SEXP ans;
-  int narm, hasna, what2;
+  int narm, hasna, what2, usenames;
   R_xlen_t ii, nrow, ncol;
+  
+  /* Coercion moved down to C */
+  PROTECT(dim = coerceVector(dim, INTSXP));
 
   /* Argument 'x' and 'dim': */
   assertArgMatrix(x, dim, (R_TYPE_LGL | R_TYPE_INT | R_TYPE_REAL), "x");
@@ -20,10 +24,10 @@ SEXP colCounts(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP value, SEXP what, SE
 
   /* Argument 'value': */
   if (length(value) != 1)
-    error("Argument 'value' must be a single value.");
+    error("Argument 'value' must be a single value");
 
   if (!isNumeric(value))
-    error("Argument 'value' must be a numeric value.");
+    error("Argument 'value' must be a numeric or a logical value");
 
   /* Argument 'what': */
   what2 = asInteger(what);
@@ -38,21 +42,22 @@ SEXP colCounts(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP value, SEXP what, SE
 
   /* Argument 'rows' and 'cols': */
   R_xlen_t nrows, ncols;
-  int rowsType, colsType;
-  void *crows = validateIndices(rows, nrow, 0, &nrows, &rowsType);
-  void *ccols = validateIndices(cols, ncol, 0, &ncols, &colsType);
-
+  int rowsHasNA;
+  int colsHasNA;
+  R_xlen_t *crows = validateIndicesCheckNA(rows, nrow, 0, &nrows, &rowsHasNA);
+  R_xlen_t *ccols = validateIndicesCheckNA(cols, ncol, 0, &ncols, &colsHasNA);
+  
   /* R allocate an integer vector of length 'ncol' */
   /* R allocate memory for vector 'count' of length 'ncols'.
      This will be taken care of by the R garbage collector later on. */
   double *count = (double *) R_alloc(ncols, sizeof(double));
 
   if (isReal(x)) {
-    colCounts_dbl[rowsType][colsType](REAL(x), nrow, ncol, crows, nrows, ccols, ncols, asReal(value), what2, narm, hasna, count);
+    colCounts_dbl(REAL(x), nrow, ncol, crows, nrows, rowsHasNA, ccols, ncols, colsHasNA, asReal(value), what2, narm, hasna, count);
   } else if (isInteger(x)) {
-    colCounts_int[rowsType][colsType](INTEGER(x), nrow, ncol, crows, nrows, ccols, ncols, asInteger(value), what2, narm, hasna, count);
+    colCounts_int(INTEGER(x), nrow, ncol, crows, nrows, rowsHasNA, ccols, ncols, colsHasNA, asInteger(value), what2, narm, hasna, count);
   } else if (isLogical(x)) {
-    colCounts_lgl[rowsType][colsType](LOGICAL(x), nrow, ncol, crows, nrows, ccols, ncols, asLogical(value), what2, narm, hasna, count);
+    colCounts_lgl(LOGICAL(x), nrow, ncol, crows, nrows, rowsHasNA, ccols, ncols, colsHasNA, asLogical(value), what2, narm, hasna, count);
   }
 
   /* Coerce counts from double to integer.  This is needed because
@@ -67,7 +72,21 @@ SEXP colCounts(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP value, SEXP what, SE
       ans_ptr[ii] = (int)count[ii];
     }
   }
-  UNPROTECT(1);
+  
+  /* Argument 'useNames': */ 
+  usenames = asLogicalNoNA(useNames, "useNames");
+  
+  if (usenames) {
+    SEXP dimnames = getAttrib(x, R_DimNamesSymbol);
+    if (dimnames != R_NilValue) {
+      SEXP namesVec = VECTOR_ELT(dimnames, 1);
+      if (namesVec != R_NilValue) {
+        setNames(ans, namesVec, ncols, ccols);
+      }
+    }
+  }
+  
+  UNPROTECT(2);
 
   return(ans);
 } // colCounts()
@@ -85,10 +104,10 @@ SEXP count(SEXP x, SEXP idxs, SEXP value, SEXP what, SEXP naRm, SEXP hasNA) {
 
   /* Argument 'value': */
   if (length(value) != 1)
-    error("Argument 'value' must be a single value.");
+    error("Argument 'value' must be a single value");
 
   if (!isNumeric(value))
-    error("Argument 'value' must be a numeric value.");
+    error("Argument 'value' must be a numeric or a logical value");
 
   /* Argument 'what': */
   what2 = asInteger(what);
@@ -101,16 +120,17 @@ SEXP count(SEXP x, SEXP idxs, SEXP value, SEXP what, SEXP naRm, SEXP hasNA) {
 
   /* Argument 'idxs': */
   R_xlen_t nrows, ncols = 1;
-  int rowsType, colsType = SUBSETTED_ALL;
-  void *crows = validateIndices(idxs, nx, 1, &nrows, &rowsType);
-  void *ccols = NULL;
+  int rowsHasNA;
+  int colsHasNA = 0;
+  R_xlen_t *crows = validateIndicesCheckNA(idxs, nx, 1, &nrows, &rowsHasNA);
+  R_xlen_t *ccols = NULL;
 
   if (isReal(x)) {
-    colCounts_dbl[rowsType][colsType](REAL(x), nx, 1, crows, nrows, ccols, ncols, asReal(value), what2, narm, hasna, &count);
+    colCounts_dbl(REAL(x), nx, 1, crows, nrows, rowsHasNA, ccols, ncols, colsHasNA, asReal(value), what2, narm, hasna, &count);
   } else if (isInteger(x)) {
-    colCounts_int[rowsType][colsType](INTEGER(x), nx, 1, crows, nrows, ccols, ncols, asInteger(value), what2, narm, hasna, &count);
+    colCounts_int(INTEGER(x), nx, 1, crows, nrows, rowsHasNA, ccols, ncols, colsHasNA, asInteger(value), what2, narm, hasna, &count);
   } else if (isLogical(x)) {
-    colCounts_lgl[rowsType][colsType](LOGICAL(x), nx, 1, crows, nrows, ccols, ncols, asLogical(value), what2, narm, hasna, &count);
+    colCounts_lgl(LOGICAL(x), nx, 1, crows, nrows, rowsHasNA, ccols, ncols, colsHasNA, asLogical(value), what2, narm, hasna, &count);
   }
 
   /* R allocate a scalar */
