@@ -29,9 +29,9 @@ SEXP colRanges(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP what, SEXP naRm, SEX
 
   /* Argument 'what': */
   if (length(what) != 1)
-    error("Argument 'what' must be a single number.");
+    error("Argument 'what' must be a single number");
   if (!isNumeric(what))
-    error("Argument 'what' must be a numeric number.");
+    error("Argument 'what' must be a numeric number");
   what2 = asInteger(what);
   if (what2 < 0 || what2 > 2)
     error("Invalid value of 'what': %d", what2);
@@ -50,7 +50,7 @@ SEXP colRanges(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP what, SEXP naRm, SEX
   R_xlen_t *ccols = validateIndicesCheckNA(cols, ncol, 0, &ncols, &colsHasNA);
   
   /* Argument 'useNames': */ 
-  usenames = asLogical(useNames);
+  usenames = asLogicalNoNA(useNames, "useNames");
 
   is_counted = (int *) R_alloc(ncols, sizeof(int));
 
@@ -61,7 +61,7 @@ SEXP colRanges(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP what, SEXP naRm, SEX
       PROTECT(ans = allocVector(REALSXP, ncols));
     }
     colRanges_dbl(REAL(x), nrow, ncol, crows, nrows, rowsHasNA, ccols, ncols, colsHasNA, what2, narm, hasna, REAL(ans), is_counted);
-    if (usenames != NA_LOGICAL && usenames) {
+    if (usenames) {
       SEXP dimnames = getAttrib(x, R_DimNamesSymbol);
       if (dimnames != R_NilValue) {
         if (what2 == 2) {
@@ -143,7 +143,7 @@ SEXP colRanges(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP what, SEXP naRm, SEX
 
       ans = ans2;
     }
-    if (usenames != NA_LOGICAL && usenames) {
+    if (usenames) {
       SEXP dimnames = getAttrib(x, R_DimNamesSymbol);
       if (dimnames != R_NilValue) {
         if (what2 == 2) {
