@@ -3,7 +3,7 @@
   void rowCumprods_<int|dbl>(ARGUMENTS_LIST)
 
  ARGUMENTS_LIST:
-  X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, R_xlen_t *rows, R_xlen_t nrows, R_xlen_t *cols, R_xlen_t ncols, int byrow, ANS_C_TYPE *ans
+  X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, R_xlen_t *rows, R_xlen_t nrows, int rowsHasNA, R_xlen_t *cols, R_xlen_t ncols, int colsHasNA, int byrow, ANS_C_TYPE *ans
 
  Arguments:
    The following macros ("arguments") should be defined for the
@@ -28,12 +28,17 @@
 
 
 void CONCAT_MACROS(rowCumprods, X_C_SIGNATURE)(X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, 
-                        R_xlen_t *rows, R_xlen_t nrows, R_xlen_t *cols, 
-                        R_xlen_t ncols, int byrow, ANS_C_TYPE *ans) {
+                        R_xlen_t *rows, R_xlen_t nrows, int rowsHasNA,
+                        R_xlen_t *cols, R_xlen_t ncols, int colsHasNA, 
+                        int byrow, ANS_C_TYPE *ans) {
   R_xlen_t ii, jj, kk, kk_prev, idx;
   R_xlen_t colBegin;
   X_C_TYPE xvalue;
   LDOUBLE value;
+  int nocols, norows;
+  
+  if (cols == NULL) { nocols = 1; } else { nocols = 0; }
+  if (rows == NULL) { norows = 1; } else { norows = 0; }
 
 #if ANS_TYPE == 'i'
   double R_INT_MIN_d = (double)R_INT_MIN,
@@ -49,10 +54,38 @@ void CONCAT_MACROS(rowCumprods, X_C_SIGNATURE)(X_C_TYPE *x, R_xlen_t nrow, R_xle
     oks = (int *) R_alloc(nrows, sizeof(int));
 #endif
 
-    colBegin = R_INDEX_OP(((cols == NULL) ? (0) : cols[0]), *, nrow);
+    if (nocols) {
+        colBegin = 0;
+    } else {
+        R_xlen_t colsFirstElement = cols[0];
+        if (!colsHasNA || colsFirstElement != NA_R_XLEN_T) {
+            colBegin = colsFirstElement * nrow;
+        } else {
+            colBegin = NA_R_XLEN_T;
+            }
+        }
+          
+    
     for (kk=0; kk < nrows; kk++) {
-      idx = R_INDEX_OP(colBegin, +, ((rows == NULL) ? (kk) : rows[kk]));
-      xvalue = R_INDEX_GET(x, idx, X_NA);
+        if (norows) {
+            if (!colsHasNA || colBegin != NA_R_XLEN_T){
+                /*
+                 * In this special case, we can eliminate
+                 * the possibility of having NA indices
+                 */
+                idx = colBegin + kk;
+                xvalue = x[idx];
+            } else {
+                xvalue = X_NA;
+            }
+        } else if (!rowsHasNA && !colsHasNA) {
+            idx = colBegin + rows[kk];
+            xvalue = x[idx];
+        } else {
+            idx = R_INDEX_OP(colBegin, +, (rows[kk]), 1, 1);
+            xvalue = R_INDEX_GET(x, idx, X_NA, 1);
+        }
+        
       ans[kk] = (ANS_C_TYPE) xvalue;
 #if ANS_TYPE == 'i'
       oks[kk] = !X_ISNA(xvalue);
@@ -61,10 +94,36 @@ void CONCAT_MACROS(rowCumprods, X_C_SIGNATURE)(X_C_TYPE *x, R_xlen_t nrow, R_xle
 
     kk_prev = 0;
     for (jj=1; jj < ncols; jj++) {
-      colBegin = R_INDEX_OP(((cols == NULL) ? (jj) : cols[jj]), *, nrow);
+        if (nocols) {
+            colBegin = jj * nrow;
+        } else {
+            R_xlen_t colsElement = cols[jj];
+            if (!colsHasNA || colsElement != NA_R_XLEN_T) {
+                colBegin = colsElement * nrow;
+            } else {
+                colBegin = NA_R_XLEN_T;
+            }
+        }
       for (ii=0; ii < nrows; ii++) {
-        idx = R_INDEX_OP(colBegin, +, ((rows == NULL) ? (ii) : rows[ii]));
-        xvalue = R_INDEX_GET(x, idx, X_NA);
+          if (norows) {
+              if (!colsHasNA || colBegin != NA_R_XLEN_T){
+                  /*
+                   * In this special case, we can eliminate
+                   * the possibility of having NA indices
+                   */
+                  idx = colBegin + ii;
+                  xvalue = x[idx];
+              } else {
+                  xvalue = X_NA;
+              }
+          } else if (!rowsHasNA && !colsHasNA) {
+              idx = colBegin + rows[ii];
+              xvalue = x[idx];
+          } else {
+              idx = R_INDEX_OP(colBegin, +, (rows[ii]), 1, 1);
+              xvalue = R_INDEX_GET(x, idx, X_NA, 1);
+          }
+          
 #if ANS_TYPE == 'i'
         if (oks[ii]) {
           if (X_ISNA(xvalue)) {
@@ -97,14 +156,39 @@ void CONCAT_MACROS(rowCumprods, X_C_SIGNATURE)(X_C_TYPE *x, R_xlen_t nrow, R_xle
   } else {
     kk = 0;
     for (jj=0; jj < ncols; jj++) {
-      colBegin = R_INDEX_OP(((cols == NULL) ? (jj) : cols[jj]), *, nrow);
+        if (nocols) {
+            colBegin = jj * nrow;
+        } else {
+            R_xlen_t colsElement = cols[jj];
+            if (!colsHasNA || colsElement != NA_R_XLEN_T) {
+                colBegin = colsElement * nrow;
+            } else {
+                colBegin = NA_R_XLEN_T;
+            }
+        }
       value = 1;
 #if ANS_TYPE == 'i'
       ok = 1;
 #endif
       for (ii=0; ii < nrows; ii++) {
-        idx = R_INDEX_OP(colBegin, +, ((rows == NULL) ? (ii) : rows[ii]));
-        xvalue = R_INDEX_GET(x, idx, X_NA);
+          if (norows) {
+              if (!colsHasNA || colBegin != NA_R_XLEN_T){
+                  /*
+                   * In this special case, we can eliminate
+                   * the possibility of having NA indices
+                   */
+                  idx = colBegin + ii;
+                  xvalue = x[idx];
+              } else {
+                  xvalue = X_NA;
+              }
+          } else if (!rowsHasNA && !colsHasNA) {
+              idx = colBegin + rows[ii];
+              xvalue = x[idx];
+          } else {
+              idx = R_INDEX_OP(colBegin, +, (rows[ii]), 1, 1);
+              xvalue = R_INDEX_GET(x, idx, X_NA, 1);
+          }
 #if ANS_TYPE == 'i'
         if (ok) {
           if (X_ISNA(xvalue)) {
