@@ -3,7 +3,7 @@
   void signTabulate_<int|dbl>(ARGUMENTS_LIST)
 
  ARGUMENTS_LIST:
-  X_C_TYPE *x, R_xlen_t nx, R_xlen_t *idxs, R_xlen_t nidxs, double *ans
+  X_C_TYPE *x, R_xlen_t nx, R_xlen_t *idxs, R_xlen_t nidxs, int idxsHasNA, double *ans
 
  Arguments:
    The following macros ("arguments") should be defined for the
@@ -22,7 +22,9 @@
 #include "000.templates-types.h"
 
 
-void CONCAT_MACROS(signTabulate, X_C_SIGNATURE)(X_C_TYPE *x, R_xlen_t nx, R_xlen_t *idxs, R_xlen_t nidxs, double *ans) {
+void CONCAT_MACROS(signTabulate, X_C_SIGNATURE)(X_C_TYPE *x, R_xlen_t nx,
+                   R_xlen_t *idxs, R_xlen_t nidxs, int idxsHasNA,
+                   double *ans) {
   X_C_TYPE xi;
   R_xlen_t ii;
   R_xlen_t nNeg = 0, nZero = 0, nPos = 0, nNA=0;
@@ -31,7 +33,7 @@ void CONCAT_MACROS(signTabulate, X_C_SIGNATURE)(X_C_TYPE *x, R_xlen_t nx, R_xlen
 #endif
 
   for (ii = 0; ii < nidxs; ii++) {
-    xi = R_INDEX_GET(x, ((idxs == NULL) ? (ii) : idxs[ii]), X_NA);
+    xi = R_INDEX_GET(x, ((idxs == NULL) ? (ii) : idxs[ii]), X_NA, idxsHasNA);
     if (X_ISNAN(xi)) {
       nNA++;
     } else if (xi > 0) {
