@@ -64,14 +64,11 @@ idxs_R2 <- indexByRow_R2(dim, idxs = idxs_by_cols)
 stopifnot(all(idxs_R2 == idxs_by_rows))
 
 
-## DEPRECATED: Backward compatibility
-idxs0 <- indexByRow(dim)
-idxs1 <- indexByRow(x)
-stopifnot(identical(idxs1, idxs0))
+## DEFUNCT: Backward compatibility
 res <- tryCatch({
   idxs1 <- indexByRow(x)
-}, warning = identity)
-stopifnot(inherits(res, "warning"))
+}, error = identity)
+stopifnot(inherits(res, "error"))
 
 
 ## Exceptions:
