@@ -1,13 +1,13 @@
 library("matrixStats")
 
-rowCumprods_R <- function(x, ..., useNames = NA) {
+rowCumprods_R <- function(x, ..., useNames = TRUE) {
   suppressWarnings({
     y <- t(apply(x, MARGIN = 1L, FUN = cumprod))
   })
 
   # Preserve dimnames attribute?
   dim(y) <- dim(x)
-  dimnames(y) <- if (isTRUE(useNames)) dimnames(x) else NULL
+  dimnames(y) <- if (useNames) dimnames(x) else NULL
   
   y
 }
@@ -30,7 +30,7 @@ for (setDimnames in c(TRUE, FALSE)) {
   for (rows in index_cases) {
     for (cols in index_cases) {
       # Check names attribute
-      for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
+      for (useNames in c(TRUE, FALSE)) {
         validateIndicesTestMatrix(x, rows, cols,
                                   ftest = rowCumprods, fsure = rowCumprods_R, useNames = useNames)
         validateIndicesTestMatrix(x, rows, cols,
