@@ -1,11 +1,11 @@
 library("matrixStats")
 
-rowDiffs_R <- function(x, lag = 1L, differences = 1L, ..., useNames = NA) {
+rowDiffs_R <- function(x, lag = 1L, differences = 1L, ..., useNames = TRUE) {
   ncol2 <- ncol(x) - lag * differences
   if (ncol2 <= 0) {
     y <- matrix(x[integer(0L)], nrow = nrow(x), ncol = 0L)
     # Preserve names attribute
-    if (isTRUE(useNames) && !is.null(rownames(x))) rownames(y) <- rownames(x)
+    if (useNames && !is.null(rownames(x))) rownames(y) <- rownames(x)
     return(y)
   }
   suppressWarnings({
@@ -15,7 +15,7 @@ rowDiffs_R <- function(x, lag = 1L, differences = 1L, ..., useNames = NA) {
   
   # Preserve dimnames attribute
   dim(y) <- c(nrow(x), ncol2)
-  if (isTRUE(useNames) && !is.null(dimnames(x))) {
+  if (useNames && !is.null(dimnames(x))) {
     colnames <- colnames(x)
     if (!is.null(colnames)) {
       len <- length(colnames)
@@ -54,7 +54,7 @@ for (mode in c("integer", "double")) {
       if (setDimnames) dimnames(x) <- dimnames
       else dimnames(x) <- NULL
       # Check dimnames attribute
-      for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
+      for (useNames in c(TRUE, FALSE)) {
         for (lag in 1:4) {
           for (differences in 1:3) {
             cat(sprintf("mode: %s, lag = %d, differences = %d\n",
@@ -90,7 +90,7 @@ for (mode in c("integer", "double")) {
     if (setDimnames) dimnames(x) <- dimnames
     else dimnames(x) <- NULL
     # Check dimnames attribute
-    for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
+    for (useNames in c(TRUE, FALSE)) {
       r0 <- rowDiffs_R(x, useNames = useNames)
       r1 <- rowDiffs(x, useNames = useNames)
       r2 <- t(colDiffs(t(x), useNames = useNames))
@@ -111,7 +111,7 @@ for (setDimnames in c(TRUE, FALSE)) {
   if (setDimnames) dimnames(x) <- dimnames
   else dimnames(x) <- NULL
   # Check dimnames attribute
-  for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
+  for (useNames in c(TRUE, FALSE)) {
     r0 <- rowDiffs_R(x, useNames = useNames)
     r1 <- rowDiffs(x, useNames = useNames)
     r2 <- t(colDiffs(t(x), useNames = useNames))
