@@ -3,28 +3,28 @@ library("matrixStats")
 ## Always allow testing of the 'center' argument (as long as it's not defunct)
 options(matrixStats.center.onUse = "ignore")
 
-rowMads_R <- function(x, na.rm = FALSE, ..., useNames = NA) {
+rowMads_R <- function(x, na.rm = FALSE, ..., useNames = TRUE) {
   suppressWarnings({
     res <- apply(x, MARGIN = 1L, FUN = mad, na.rm = na.rm)
   })
-  if (is.na(useNames) || !useNames) names(res) <- NULL
+  if (!useNames) names(res) <- NULL
   res
 }
 
-colMads_R <- function(x, na.rm = FALSE, ..., useNames = NA) {
+colMads_R <- function(x, na.rm = FALSE, ..., useNames = TRUE) {
   suppressWarnings({
     res <- apply(x, MARGIN = 2L, FUN = mad, na.rm = na.rm)
   })
-  if (is.na(useNames) || !useNames) names(res) <- NULL
+  if (!useNames) names(res) <- NULL
   res
 }
 
-rowMads_center <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, ..., useNames = NA) {
+rowMads_center <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, ..., useNames = TRUE) {
   center <- rowMedians(x, cols = cols, na.rm = na.rm, useNames = FALSE)
   rowMads(x, rows = rows, cols = cols, center = center, na.rm = na.rm, useNames = useNames)
 }
 
-colMads_center <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, ..., useNames = NA) {
+colMads_center <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, ..., useNames = TRUE) {
   center <- colMedians(x, rows = rows, na.rm = na.rm, useNames = FALSE)
   colMads(x, rows = rows, cols = cols, center = center, na.rm = na.rm, useNames = useNames)
 }
@@ -50,7 +50,7 @@ for (setDimnames in c(TRUE, FALSE)) {
     for (cols in index_cases) {
       count <- count + 1L
       na.rm <- c(TRUE, FALSE)[count %% 2 + 1]
-      useNames <- c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)
+      useNames <- c(TRUE, FALSE)
       useNames <- useNames[count %% length(useNames) + 1]
       
       validateIndicesTestMatrix(x, rows, cols,
