@@ -8,7 +8,7 @@ if (!exists("isFALSE", mode="function")) {
   isFALSE <- function(x) is.logical(x) && length(x) == 1L && !is.na(x) && !x
 }
 
-rowVars_R <- function(x, na.rm = FALSE, center = NULL, ..., useNames = NA) {
+rowVars_R <- function(x, na.rm = FALSE, center = NULL, ..., useNames = TRUE) {
   suppressWarnings({
     res <- apply(x, MARGIN = 1L, FUN = var, na.rm = na.rm)
   })
@@ -16,13 +16,13 @@ rowVars_R <- function(x, na.rm = FALSE, center = NULL, ..., useNames = NA) {
   
   # Keep naming support consistency same as rowVars()
   if (is.null(center) || ncol(x) <= 1L) {
-    if (is.na(useNames) || isFALSE(useNames)) names(res) <- NULL
+    if (isFALSE(useNames)) names(res) <- NULL
   }
   else if (isFALSE(useNames)) names(res) <- NULL
   res
 }
 
-colVars_R <- function(x, na.rm = FALSE, center = NULL, ..., useNames = NA) {
+colVars_R <- function(x, na.rm = FALSE, center = NULL, ..., useNames = TRUE) {
   suppressWarnings({
     res <- apply(x, MARGIN = 2L, FUN = var, na.rm = na.rm)
   })
@@ -30,21 +30,21 @@ colVars_R <- function(x, na.rm = FALSE, center = NULL, ..., useNames = NA) {
   
   # Keep naming support consistency same as colVars()
   if (is.null(center) || nrow(x) <= 1L) {
-    if (is.na(useNames) || isFALSE(useNames)) names(res) <- NULL
+    if (isFALSE(useNames)) names(res) <- NULL
   }
   else if (isFALSE(useNames)) names(res) <- NULL
   res
 }
 
 
-rowVars_center <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, ..., useNames = NA) {
+rowVars_center <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, ..., useNames = TRUE) {
   center <- rowWeightedMeans(x, cols = cols, na.rm = na.rm, useNames = FALSE)
   res <- rowVars(x, rows = rows, cols = cols, center = center, na.rm = na.rm, useNames = useNames)
   stopifnot(!any(is.infinite(res)))
   res
 }
 
-colVars_center <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, ..., useNames = NA) {
+colVars_center <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, ..., useNames = TRUE) {
   center <- colWeightedMeans(x, rows = rows, na.rm = na.rm, useNames = FALSE)
   res <- colVars(x, rows = rows, cols = cols, center = center, na.rm = na.rm, useNames = useNames)
   stopifnot(!any(is.infinite(res)))
@@ -72,7 +72,7 @@ for (setDimnames in c(TRUE, FALSE)) {
     for (cols in index_cases) {
       count <- count + 1L
       na.rm <- c(TRUE, FALSE)[count %% 2 + 1]
-      useNames <- c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)
+      useNames <- c(TRUE, FALSE)
       useNames <- useNames[count %% length(useNames) + 1]
       
       validateIndicesTestMatrix(x, rows, cols,
