@@ -5,7 +5,7 @@ if (!exists("isFALSE", mode="function")) {
   isFALSE <- function(x) is.logical(x) && length(x) == 1L && !is.na(x) && !x
 }
 
-rowWeightedMeans_R <- function(x, w, na.rm = FALSE, ..., useNames = NA) {
+rowWeightedMeans_R <- function(x, w, na.rm = FALSE, ..., useNames = TRUE) {
   res <- apply(x, MARGIN = 1L, FUN = weighted.mean, w = w, na.rm = na.rm, ...)
   
   # Keep naming support consistency same as rowWeightedMeans()
@@ -13,21 +13,21 @@ rowWeightedMeans_R <- function(x, w, na.rm = FALSE, ..., useNames = NA) {
   nw <- length(idxs)
   if (na.rm) na.rm <- anyMissing(x)
   if ((!is.null(w) && nw == 0L) || isFALSE(na.rm)) {
-    if (is.na(useNames) || !useNames) names(res) <- NULL
+    if (!useNames) names(res) <- NULL
   }
   else if (isFALSE(useNames)) names(res) <- NULL
   
   res
 }
 
-colWeightedMeans_R <- function(x, w, na.rm = FALSE, ..., useNames = NA) {
+colWeightedMeans_R <- function(x, w, na.rm = FALSE, ..., useNames = TRUE) {
   res <- apply(x, MARGIN = 1L, FUN = weighted.mean, w = w, na.rm = na.rm, ...)
   
   # Keep naming support consistency same as colWeightedMeans()
   idxs <- which(is.na(w) | w != 0)
   nw <- length(idxs)
   if (!is.null(w) && nw == 0L) {
-    if (is.na(useNames) || !useNames) names(res) <- NULL
+    if (!useNames) names(res) <- NULL
   }
   else if (isFALSE(useNames)) names(res) <- NULL
   
@@ -58,7 +58,7 @@ for (mode in c("numeric", "integer", "logical")) {
       for (cols in index_cases) {
         count <- count + 1L
         na.rm <- c(TRUE, FALSE)[count %% 2 + 1]
-        useNames <- c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)
+        useNames <- c(TRUE, FALSE)
         useNames <- useNames[count %% length(useNames) + 1]
 
         validateIndicesTestMatrix_w(x, w, rows, cols, 
